pub struct Priority(pub i8);Expand description
Priority of this presence. This value can go from -128 to 127, defaults to 0, and any negative value will prevent this resource from receiving messages addressed to the bare JID.
Tuple Fields
0: i8Trait Implementations
Sourceimpl AsXml for Priority
impl AsXml for Priority
Sourceimpl FromXml for Priority
impl FromXml for Priority
Sourcefn from_events(
name: QName,
attrs: AttrMap,
ctx: &Context<'_>,
) -> Result<Self::Builder, FromEventsError>
fn from_events( name: QName, attrs: AttrMap, ctx: &Context<'_>, ) -> Result<Self::Builder, FromEventsError>
Attempt to initiate the streamed construction of this struct from XML. Read more
Sourcefn xml_name_matcher() -> XmlNameMatcher<'static>
fn xml_name_matcher() -> XmlNameMatcher<'static>
Return a predicate which determines if
Self may be parsed from
a given XML element. Read moreimpl StructuralPartialEq for Priority